==> bluebox-ng-0.1.2.tgz: package/utils/printer.js <==
/*
Copyright Jesus Perez <jesusprubio gmail com>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

'use strict';

var clc        = require('cli-color'),
    prettyjson = require('prettyjson');


// Public functions

module.exports.regular = function (str) {
    console.log(str);
};
        
module.exports.info = function (str) {
    console.log(clc.xterm(55)(str));
};
        
module.exports.infoHigh = function (str) {
    console.log(clc.xterm(63)(str));
};

module.exports.highlight = function (str) {
    console.log(clc.xterm(202)(str));
};

// TODO: Some beautifull JSON printer
module.exports.result = function (str) {
    console.log(clc.xterm(46)(str));
};

module.exports.json = function (json) {
    console.log(prettyjson.render(json, {
//        keysColor: 'rainbow',
//        dashColor: 'magenta',
//        stringColor: 'white'
    }));
};

module.exports.error = function (str) {
    console.log(clc.red.bold(str));
};

module.exports.bold = function (str) {
    console.log(clc.bold(str));
};

module.exports.clear = function () {
    console.log(clc.reset);
};

module.exports.remove = function (pos) {
    console.log(clc.bol(-pos));
};

==> bluebox-ng-0.1.4.tgz: package/utils/printer.js <==
/*
Copyright Jesus Perez <jesusprubio gmail com>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

'use strict';

var clc        = require('cli-color'),
    prettyjson = require('prettyjson');


// Public functions

module.exports.regular = function (str) {
    process.stdout.write(str + '\n');
};

module.exports.info = function (str) {
    process.stdout.write(clc.xterm(55)(str) + '\n');
};

module.exports.infoHigh = function (str) {
    process.stdout.write(clc.xterm(63)(str) + '\n');
};

module.exports.highlight = function (str) {
    process.stdout.write(clc.xterm(202)(str) + '\n');
};

// TODO: Some beautifull JSON printer
module.exports.result = function (str) {
    process.stdout.write(clc.xterm(46)(str) + '\n');
};

module.exports.json = function (json) {
    process.stdout.write(prettyjson.render(json, {
//        keysColor: 'rainbow',
//        dashColor: 'magenta',
//        stringColor: 'white'
    }) + '\n');
};

module.exports.error = function (str) {
    process.stdout.write(clc.red.bold(str) + '\n');
};

module.exports.bold = function (str) {
    process.stdout.write(clc.bold(str) + '\n');
};

module.exports.clear = function () {
    process.stdout.write(clc.reset);
};

module.exports.remove = function (pos) {
    process.stdout.write(clc.bol(-pos) + '\n');
};
